diff -pruN 5.1.1-1/.github/workflows/check.yml 5.1.2-1/.github/workflows/check.yml
--- 5.1.1-1/.github/workflows/check.yml	1970-01-01 00:00:00.000000000 +0000
+++ 5.1.2-1/.github/workflows/check.yml	2024-04-22 07:58:36.000000000 +0000
@@ -0,0 +1,74 @@
+name: CI
+
+on:
+  push:
+    branches:
+      - master
+  pull_request:
+    branches:
+      - master
+
+jobs:
+  check:
+    name: Build and test
+    runs-on: ubuntu-latest
+    container: archlinux:latest
+    strategy:
+      fail-fast: false
+      matrix:
+        compiler: [gcc, clang]
+        include:
+          - compiler: gcc
+            cxx_compiler: g++
+          - compiler: clang
+            cxx_compiler: clang++
+    env:
+      CC: ${{ matrix.compiler }}
+      CXX: ${{ matrix.cxx_compiler }}
+    steps:
+      - name: Install dependencies
+        run: |
+          pacman -Syu --noconfirm base-devel clang cmake ninja extra-cmake-modules fmt libuv boost git
+      - uses: actions/checkout@v4
+        with:
+          repository: fcitx/fcitx5
+          path: fcitx5
+      - name: Cache fcitx5 data files
+        uses: actions/cache@v4
+        with:
+          path: 'fcitx5/**/*.tar.*'
+          key: ${{ runner.os }}-${{ hashFiles('fcitx5/src/modules/spell/CMakeLists.txt') }}
+      - name: Build and Install fcitx5
+        uses: fcitx/github-actions@cmake
+        with:
+          path: fcitx5
+          cmake-option: >-
+            -DENABLE_KEYBOARD=Off
+            -DENABLE_X11=Off
+            -DENABLE_WAYLAND=Off
+            -DENABLE_ENCHANT=Off
+            -DENABLE_DBUS=Off
+            -DENABLE_SERVER=Off
+            -DENABLE_EMOJI=Off
+            -DUSE_SYSTEMD=Off
+      - uses: actions/checkout@v4
+        with:
+          repository: fcitx/libime
+          path: libime
+          submodules: true
+      - name: Cache libime data files
+        uses: actions/cache@v4
+        with:
+          path: 'libime/**/*.tar.*'
+          key: ${{ runner.os }}-${{ hashFiles('libime/data/CMakeLists.txt') }}
+      - name: Build and Install libime
+        uses: fcitx/github-actions@cmake
+        with:
+          path: libime
+      - uses: actions/checkout@v4
+        with:
+          path: fcitx5-table-other
+      - name: Build and Install fcitx5-table-other
+        uses: fcitx/github-actions@cmake
+        with:
+          path: fcitx5-table-other
diff -pruN 5.1.1-1/CMakeLists.txt 5.1.2-1/CMakeLists.txt
--- 5.1.1-1/CMakeLists.txt	2024-02-29 00:06:33.129440800 +0000
+++ 5.1.2-1/CMakeLists.txt	2024-04-22 07:58:36.000000000 +0000
@@ -1,5 +1,5 @@
 cmake_minimum_required(VERSION 3.8)
-project(fcitx-table-other VERSION 5.1.1)
+project(fcitx-table-other VERSION 5.1.2)
 
 find_package(ECM 1.0 REQUIRED)
 set(CMAKE_MODULE_PATH ${ECM_MODULE_PATH} "${CMAKE_CURRENT_SOURCE_DIR}/cmake" ${CMAKE_MODULE_PATH})
diff -pruN 5.1.1-1/debian/changelog 5.1.2-1/debian/changelog
--- 5.1.1-1/debian/changelog	2024-03-19 14:09:59.000000000 +0000
+++ 5.1.2-1/debian/changelog	2024-05-09 18:14:43.000000000 +0000
@@ -1,3 +1,9 @@
+fcitx5-table-other (5.1.2-1) unstable; urgency=medium
+
+  * New upstream release.
+
+ -- Boyuan Yang <byang@debian.org>  Thu, 09 May 2024 14:14:43 -0400
+
 fcitx5-table-other (5.1.1-1) unstable; urgency=medium
 
   * New upstream release.
diff -pruN 5.1.1-1/debian/control 5.1.2-1/debian/control
--- 5.1.1-1/debian/control	2023-06-16 22:49:50.000000000 +0000
+++ 5.1.2-1/debian/control	2024-05-09 18:14:42.000000000 +0000
@@ -14,7 +14,7 @@ Build-Depends:
  libime-bin,
  libimecore-dev,
  libimetable-dev,
-Standards-Version: 4.6.2
+Standards-Version: 4.7.0
 Homepage: https://github.com/fcitx/fcitx5-table-other
 Vcs-Git: https://salsa.debian.org/input-method-team/fcitx5-table-other.git
 Vcs-Browser: https://salsa.debian.org/input-method-team/fcitx5-table-other
diff -pruN 5.1.1-1/org.fcitx.Fcitx5.Addon.TableOther.metainfo.xml.in 5.1.2-1/org.fcitx.Fcitx5.Addon.TableOther.metainfo.xml.in
--- 5.1.1-1/org.fcitx.Fcitx5.Addon.TableOther.metainfo.xml.in	2024-02-29 00:06:33.152773400 +0000
+++ 5.1.2-1/org.fcitx.Fcitx5.Addon.TableOther.metainfo.xml.in	2024-04-22 07:58:36.000000000 +0000
@@ -6,10 +6,15 @@
   <project_license>GPL-3.0+</project_license>
   <name>Additional Table for Fcitx 5</name>
   <summary>Additional table based input method for Fcitx 5</summary>
+  <developer id="org.fcitx-im">
+      <name>The Fcitx Team</name>
+  </developer>
   <url type="homepage">https://fcitx-im.org</url>
   <url type="bugtracker">https://github.com/fcitx/fcitx5-table-other/issues</url>
+  <url type="vcs-browser">https://github.com/fcitx/fcitx5-table-other</url>
   <project_group>Fcitx</project_group>
   <releases>
+    <release version="5.1.2" date="2024-04-22"/>
     <release version="5.1.1" date="2024-02-28"/>
     <release version="5.1.0" date="2023-08-14"/>
     <release version="5.0.11" date="2023-03-10"/>
diff -pruN 5.1.1-1/po/he.po 5.1.2-1/po/he.po
--- 5.1.1-1/po/he.po	2023-04-13 00:46:55.443907300 +0000
+++ 5.1.2-1/po/he.po	2024-04-22 07:58:36.000000000 +0000
@@ -9,7 +9,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: fcitx5-table-other\n"
 "Report-Msgid-Bugs-To: fcitx-dev@googlegroups.com\n"
-"POT-Creation-Date: 2023-04-12 14:27+0000\n"
+"POT-Creation-Date: 2024-03-05 20:24+0000\n"
 "PO-Revision-Date: 2020-09-13 02:33+0000\n"
 "Last-Translator: 63f334ffc0709ba0fc2361b80bf3c0f0_00ffd1e "
 "<ab96c93ca0ac55ba7fa06385427e60dd_878890>, 2021\n"
@@ -18,8 +18,8 @@ msgstr ""
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"Plural-Forms: nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % "
-"1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;\n"
+"Plural-Forms: nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % "
+"1 == 0) ? 1: 2;\n"
 
 #: org.fcitx.Fcitx5.Addon.TableOther.metainfo.xml.in:7
 msgid "Additional Table for Fcitx 5"
